@@ -406,6 +406,90 @@ class TestQuery(TestCase):
         self.assertEqual(len(result), 1)
         self.assertEqual(result[0].name, 'Lucy')
 
+    def test_query_object_with_gt_str_object(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song2.save()
+        result = SimpleSong.find(name={'_gt': 'b'}).exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].name, 'c')
+
+    def test_query_object_with_gt_str_object_str(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song2.save()
+        result = SimpleSong.find('name[_gt]=b').exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].name, 'c')
+
+    def test_query_object_with_gte_str_object(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='b', year=2020, artist='Lieng')
+        song2.save()
+        song3 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song3.save()
+        result = SimpleSong.find(name={'_gte': 'b'}).exec()
+        self.assertEqual(len(result), 2)
+        self.assertEqual(result[0].name, 'b')
+        self.assertEqual(result[1].name, 'c')
+
+    def test_query_object_with_gte_str_object_str(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='b', year=2020, artist='Lieng')
+        song2.save()
+        song3 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song3.save()
+        result = SimpleSong.find('name[_gte]=b').exec()
+        self.assertEqual(len(result), 2)
+        self.assertEqual(result[0].name, 'b')
+        self.assertEqual(result[1].name, 'c')
+
+    def test_query_object_with_lt_str_object(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song2.save()
+        result = SimpleSong.find(name={'_lt': 'b'}).exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].name, 'a')
+
+    def test_query_object_with_lt_str_object_str(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song2.save()
+        result = SimpleSong.find('name[_lt]=b').exec()
+        self.assertEqual(len(result), 1)
+        self.assertEqual(result[0].name, 'a')
+
+    def test_query_object_with_lte_str_object(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='b', year=2020, artist='Lieng')
+        song2.save()
+        song3 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song3.save()
+        result = SimpleSong.find(name={'_lte': 'b'}).exec()
+        self.assertEqual(len(result), 2)
+        self.assertEqual(result[0].name, 'a')
+        self.assertEqual(result[1].name, 'b')
+
+    def test_query_object_with_lte_str_object_str(self):
+        song = SimpleSong(name='a', year=2020, artist='Thao')
+        song.save()
+        song2 = SimpleSong(name='b', year=2020, artist='Lieng')
+        song2.save()
+        song3 = SimpleSong(name='c', year=2020, artist='Lieng')
+        song3.save()
+        result = SimpleSong.find('name[_lte]=b').exec()
+        self.assertEqual(len(result), 2)
+        self.assertEqual(result[0].name, 'a')
+        self.assertEqual(result[1].name, 'b')
+
     def test_query_object_with_equal_str_object(self):
         song = SimpleSong(name='Lucy', year=2020, artist='Thao')
         song.save()
