@@ -4,6 +4,7 @@ from jsonclasses.excs import UniqueConstraintException
 from jsonclasses_pymongo import Connection
 from tests.classes.simple_person import SimplePerson
 from tests.classes.simple_singer import SimpleSinger
+from tests.classes.simple_album import SimpleAlbum
 
 
 class TestUniqueRecord(TestCase):
@@ -24,6 +25,8 @@ class TestUniqueRecord(TestCase):
         collection.delete_many({})
         collection = Connection.get_collection(SimpleSinger)
         collection.delete_many({})
+        collection = Connection.get_collection(SimpleAlbum)
+        collection.delete_many({})
 
     def test_save_raises_if_violate_unique_rule(self):
         one = SimplePerson(name='Tsuan Tsiu')
@@ -39,10 +42,27 @@ class TestUniqueRecord(TestCase):
         one.save()
         two = SimpleSinger(name=None)
         two.save()
-        one = SimplePerson(name='Tsuan Tsiu')
+
+    def test_save_raises_if_all_values_violates_cunique_rule(self):
+        one = SimpleAlbum(name='n', year=2021, note='n')
         one.save()
-        two = SimplePerson(name='Tsuan Tsiu')
-        self.assertRaisesRegex(
-            UniqueConstraintException,
-            "value is not unique",
-            two.save)
+        two = SimpleAlbum(name='n', year=2021, note='n')
+        self.assertRaisesRegex(UniqueConstraintException, "voilated unique compound index 'com'", two.save)
+
+    def test_save_raises_if_part_of_values_violates_cunique_rule(self):
+        one = SimpleAlbum(name='n', year=2021, note=None)
+        one.save()
+        two = SimpleAlbum(name='n', year=2021, note=None)
+        self.assertRaisesRegex(UniqueConstraintException, "voilated unique compound index 'com'", two.save)
+
+    def test_save_raises_if_one_value_violates_cunique_rule(self):
+        one = SimpleAlbum(name='n')
+        one.save()
+        two = SimpleAlbum(name='n')
+        self.assertRaisesRegex(UniqueConstraintException, "voilated unique compound index 'com'", two.save)
+
+    def test_save_wont_raise_if_all_values_are_null(self):
+        one = SimpleAlbum()
+        one.save()
+        two = SimpleAlbum()
+        two.save()
